@@ -18,7 +18,7 @@ class Configuration(object):
 
     # Set the array parameter serialization method
     # (allowed: indexed, unindexed, plain, csv, tsv, psv)
-    array_serialization = "indexed"
+    array_serialization = "csv"
 
     # True if the client should skip verification of SSL certificates
     skip_ssl_verification = True
@@ -106,4 +106,4 @@ class Configuration(object):
             logging.basicConfig(stream=stream, level=level)
         else:
             logging.basicConfig(filename=filename, filemode=filemode,
-                                level=level)
\ No newline at end of file
+                                level=level)
