@@ -1,46 +1,60 @@
 __all__ = [
-    'base_controller',
     'access_tokens_controller',
     'active_directory_controller',
     'alerts_controller',
+    'analytics_controller',
     'antivirus_service_group_controller',
+    'app_controller',
+    'app_instance_controller',
     'audit_controller',
-    'cluster_controller',
+    'banner_controller',
+    'base_controller',
     'certificates_controller',
-    'clusters_controller',
+    'clone_refresh_tasks_controller',
+    'cluster_controller',
     'cluster_partitions_controller',
+    'clusters_controller',
+    'custom_reporting_controller',
+    'dashboard_controller',
     'groups_controller',
     'idps_controller',
+    'interface_controller',
     'interface_group_controller',
+    'ip_controller',
     'kms_configuration_controller',
+    'kms_configuration_response_controller',
+    'kms_update_request_parameters_controller',
     'ldap_provider_controller',
+    'license_controller',
+    'monitoring_controller',
     'network_controller',
-    'views_controller',
     'nodes_controller',
+    'notifications_controller',
     'packages_controller',
-    'protection_sources_controller',
-    'custom_reporting_controller',
+    'preferences_controller',
     'principals_controller',
     'privileges_controller',
     'protection_jobs_controller',
     'protection_objects_controller',
     'protection_policies_controller',
     'protection_runs_controller',
+    'protection_sources_controller',
     'remote_cluster_controller',
     'remote_restore_controller',
     'reports_controller',
     'restore_tasks_controller',
     'roles_controller',
     'routes_controller',
+    'scheduler_controller',
     'search_controller',
-    'notifications_controller',
-    'preferences_controller',
     'smb_file_opens_controller',
-    'static_route_controller',
     'statistics_controller',
+    'stats_controller',
+    'tags_controller',
     'tenant_controller',
     'tenants_controller',
     'vaults_controller',
     'view_boxes_controller',
-    'vlan_controller',
-]
\ No newline at end of file
+    'views_controller',
+    'vlan_controller'
+]
