@@ -6,6 +6,7 @@ from cohesity_management_sdk.api_helper import APIHelper
 from cohesity_management_sdk.configuration import Configuration
 from cohesity_management_sdk.controllers.base_controller import BaseController
 from cohesity_management_sdk.http.auth.auth_manager import AuthManager
+from cohesity_management_sdk.models.apps_config import AppsConfig
 from cohesity_management_sdk.models.basic_cluster_info import BasicClusterInfo
 from cohesity_management_sdk.models.cluster import Cluster
 from cohesity_management_sdk.models.cluster_status_result import ClusterStatusResult
@@ -196,6 +197,123 @@ class ClusterController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
+    def get_app_settings(self):
+        """Does a GET request to /public/cluster/appSettings.
+
+        Returns the app settings for the cluster.
+
+        Returns:
+            AppsConfig: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('get_app_settings called.')
+
+            # Prepare query URL
+            self.logger.info('Preparing query URL for get_app_settings.')
+            _url_path = '/public/cluster/appSettings'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for get_app_settings.')
+            _headers = {'accept': 'application/json'}
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for get_app_settings.')
+            _request = self.http_client.get(_query_url, headers=_headers)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request,
+                                            name='get_app_settings')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for get_app_settings.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body,
+                AppsConfig.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
+    def update_app_settings(self, body=None):
+        """Does a PUT request to /public/cluster/appSettings.
+
+        Returns the updated app settings.
+
+        Args:
+            body (AppsConfig): Update App Settings Parameter.
+
+        Returns:
+            AppsConfig: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('update_app_settings called.')
+
+            # Prepare query URL
+            self.logger.info(
+                'Preparing query URL for update_app_settings.')
+            _url_path = '/public/cluster/appSettings'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info(
+                'Preparing headers for update_app_settings.')
+            _headers = {
+                'accept': 'application/json',
+                'content-type': 'application/json; charset=utf-8'
+            }
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for update_app_settings.'
+            )
+            _request = self.http_client.put(
+                _query_url,
+                headers=_headers,
+                parameters=APIHelper.json_serialize(body))
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request,
+                                            name='update_app_settings')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info(
+                'Validating response for update_app_settings.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body,
+                AppsConfig.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
     def get_cluster_status(self):
         """Does a GET request to /public/cluster/status.
 
