@@ -13,6 +13,13 @@ class AwsCredentials(object):
         amazon_resource_name (string): Specifies Amazon Resource Name (owner
             ID) of the IAM user, act as an unique identifier of as AWS
             entity.
+        auth_method (AuthMethodEnum): Specifies the iauth method used for the
+            request. See the Cohesity online help for the value to specify for
+            this field based on the current S3-compatible Vault (External
+            Target) type. Specifies the authentication method to be used for
+            API calls. 'kUseIAMUser' indicates a user based authentication.
+            'kUseIAMRole' indicates a role based authentication, used only for
+            AWS CE.
         aws_type (AwsTypeEnum): Specifies the entity type such as 'kIAMUser'
             if the environment is kAWS. Specifies the type of an AWS source
             entity. 'kIAMUser' indicates a unique user within an AWS account.
@@ -30,6 +37,10 @@ class AwsCredentials(object):
             RDS parameter group. 'kRDSInstance' represents a RDS DB instance.
             'kRDSSubnet' represents a RDS subnet. 'kRDSTag' represents a tag
             attached to RDS instance.
+        iam_role_arn (string): Specifies the iam role arn Amazon service
+            account. See the Cohesity online help for the value to specify for
+            this field based on the current S3-compatible Vault (External
+            Target) type.
         secret_access_key (string): Specifies Secret Access key of the AWS
             account.
         subscription_type (SubscriptionTypeEnum): Specifies the subscription
@@ -44,7 +55,9 @@ class AwsCredentials(object):
     _names = {
         "access_key":'accessKey',
         "amazon_resource_name":'amazonResourceName',
+        "auth_method":'authMethod',
         "aws_type":'awsType',
+        "iam_role_arn":'iamRoleArn',
         "secret_access_key":'secretAccessKey',
         "subscription_type":'subscriptionType'
     }
@@ -52,7 +65,9 @@ class AwsCredentials(object):
     def __init__(self,
                  access_key=None,
                  amazon_resource_name=None,
+                 auth_method=None,
                  aws_type=None,
+                 iam_role_arn=None,
                  secret_access_key=None,
                  subscription_type=None):
         """Constructor for the AwsCredentials class"""
@@ -60,7 +75,9 @@ class AwsCredentials(object):
         # Initialize members of the class
         self.access_key = access_key
         self.amazon_resource_name = amazon_resource_name
+        self.auth_method = auth_method
         self.aws_type = aws_type
+        self.iam_role_arn = iam_role_arn
         self.secret_access_key = secret_access_key
         self.subscription_type = subscription_type
 
@@ -85,14 +102,18 @@ class AwsCredentials(object):
         # Extract variables from the dictionary
         access_key = dictionary.get('accessKey')
         amazon_resource_name = dictionary.get('amazonResourceName')
+        auth_method = dictionary.get('authMethod')
         aws_type = dictionary.get('awsType')
+        iam_role_arn = dictionary.get('iamRoleArn')
         secret_access_key = dictionary.get('secretAccessKey')
         subscription_type = dictionary.get('subscriptionType')
 
         # Return an object of this model
         return cls(access_key,
                    amazon_resource_name,
+                   auth_method,
                    aws_type,
+                   iam_role_arn,
                    secret_access_key,
                    subscription_type)
 
