@@ -8,11 +8,13 @@ class CompressionPolicyVaultEnum(object):
     Specifies whether to send data to the Vault in a
     compressed format.
     'kCompressionNone' indicates that data is not compressed.
-    'kCompressionLow' indicates that data is compressed.
+    'kCompressionLow' indicates that data is compressed using LZ4 or Snappy.
+    'kCompressionHigh' indicates that data is compressed in Gzip.
 
     Attributes:
         KCOMPRESSIONNONE: TODO: type description here.
         KCOMPRESSIONLOW: TODO: type description here.
+        KCOMPRESSIONHIGH: TODO: type description here.
 
     """
 
@@ -20,3 +22,5 @@ class CompressionPolicyVaultEnum(object):
 
     KCOMPRESSIONLOW = 'kCompressionLow'
 
+    KCOMPRESSIONHIGH = 'kCompressionHigh'
+
