@@ -9,25 +9,25 @@ class CreateApiKeyParams(object):
     Specifies the parameters to create an API key.
 
     Attributes:
-        expiring_time_msecs (long|int): Specifies a time stamp when the API
+        expiring_time_msecs (int|long): Specifies a time stamp when the API
             key will expire in milli seconds.
         is_active (bool): Specifies if the API key is active. Only an active
             and not expired API key can be used for authentication.
-        name (string): Specifies the name of API key.
+        name (string, required): Specifies the name of API key.
 
     """
 
     # Create a mapping from Model property names to API property names
     _names = {
-        "name":'name',
         "expiring_time_msecs":'expiringTimeMsecs',
-        "is_active":'isActive'
+        "is_active":'isActive',
+        "name":'name'
     }
 
     def __init__(self,
-                 name=None,
                  expiring_time_msecs=None,
-                 is_active=None):
+                 is_active=None,
+                 name=None):
         """Constructor for the CreateApiKeyParams class"""
 
         # Initialize members of the class
@@ -54,13 +54,13 @@ class CreateApiKeyParams(object):
             return None
 
         # Extract variables from the dictionary
-        name = dictionary.get('name')
         expiring_time_msecs = dictionary.get('expiringTimeMsecs')
         is_active = dictionary.get('isActive')
+        name = dictionary.get('name')
 
         # Return an object of this model
-        return cls(name,
-                   expiring_time_msecs,
-                   is_active)
+        return cls(expiring_time_msecs,
+                   is_active,
+                   name)
 
 
