@@ -19,6 +19,7 @@ class EnvironmentListProtectionSourcesEnum(object):
         KHYPERV: TODO: type description here.
         KACROPOLIS: TODO: type description here.
         KAZURE: TODO: type description here.
+        KKUBERNETES: TODO: type description here.
 
     """
 
@@ -44,3 +45,5 @@ class EnvironmentListProtectionSourcesEnum(object):
 
     KAZURE = 'kAzure'
 
+    KKUBERNETES = 'kKubernetes'
+
