@@ -11,6 +11,7 @@ class ObjectClassSearchActiveDirectoryPrincipalsEnum(object):
         KUSER: TODO: type description here.
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
+        KWELLKNOWNPRINCIPAL: TODO: type description here.
 
     """
 
@@ -20,3 +21,5 @@ class ObjectClassSearchActiveDirectoryPrincipalsEnum(object):
 
     KCOMPUTER = 'kComputer'
 
+    KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
+
