@@ -9,8 +9,13 @@ class Office365UserInfo(object):
     Specifies information about an Office365 user.
 
     Attributes:
+        city (string): Specifies the city in which the Office365 user is
+            located.
+        country (string): Specifies the country/region in which the Office365
+            user is located.
         department (string): Specifies the department within the enterprise of
             the Office365 user.
+        designation (string): Specifies the designation of the Office365 user.
         graph_uuid (string): Specifies the MS Graph UUID for the given user
             entity.
         mailbox_size (long|int): Specifies the size of the Outlook Mailbox
@@ -24,7 +29,10 @@ class Office365UserInfo(object):
 
     # Create a mapping from Model property names to API property names
     _names = {
+        "city":'city',
+        "country":'country',
         "department":'department',
+        "designation":'designation',
         "graph_uuid":'graphUuid',
         "mailbox_size":'mailboxSize',
         "one_drive_id":'oneDriveId',
@@ -32,7 +40,10 @@ class Office365UserInfo(object):
     }
 
     def __init__(self,
+                 city=None,
+                 country=None,
                  department=None,
+                 designation=None,
                  graph_uuid=None,
                  mailbox_size=None,
                  one_drive_id=None,
@@ -40,7 +51,10 @@ class Office365UserInfo(object):
         """Constructor for the Office365UserInfo class"""
 
         # Initialize members of the class
+        self.city = city
+        self.country = country
         self.department = department
+        self.designation = designation
         self.graph_uuid = graph_uuid
         self.mailbox_size = mailbox_size
         self.one_drive_id = one_drive_id
@@ -65,14 +79,20 @@ class Office365UserInfo(object):
             return None
 
         # Extract variables from the dictionary
+        city = dictionary.get('city')
+        country = dictionary.get('country')
         department = dictionary.get('department')
+        designation = dictionary.get('designation')
         graph_uuid = dictionary.get('graphUuid')
         mailbox_size = dictionary.get('mailboxSize')
         one_drive_id = dictionary.get('oneDriveId')
         one_drive_size = dictionary.get('oneDriveSize')
 
         # Return an object of this model
-        return cls(department,
+        return cls(city,
+                   country,
+                   department,
+                   designation,
                    graph_uuid,
                    mailbox_size,
                    one_drive_id,
