@@ -22,6 +22,10 @@ class PhysicalSpecialParameters(object):
         file_paths (list of FilePathParameters): Array of File Paths to Back
             Up.  Specifies a list of directories or files to protect in a
             Physical Server.
+        metadata_file_path (string): Specifies metadata path on source. This
+            file contains absolute paths of files that needs to be backed up
+            on the same source. If this field is set, backup_path_info_vec
+            will be ignored.
         skip_nested_volumes_vec (list of string): Specifies mounttypes of
             nested volumes to be skipped.
         uses_skip_nested_volumes_vec (bool): Specifies whether to use
@@ -40,6 +44,7 @@ class PhysicalSpecialParameters(object):
         "application_parameters":'applicationParameters',
         "enable_system_backup":'enableSystemBackup',
         "file_paths":'filePaths',
+        "metadata_file_path":'metadataFilePath',
         "skip_nested_volumes_vec":'skipNestedVolumesVec',
         "uses_skip_nested_volumes_vec":'usesSkipNestedVolumesVec',
         "volume_guid":'volumeGuid',
@@ -50,6 +55,7 @@ class PhysicalSpecialParameters(object):
                  application_parameters=None,
                  enable_system_backup=None,
                  file_paths=None,
+                 metadata_file_path=None,
                  skip_nested_volumes_vec=None,
                  uses_skip_nested_volumes_vec=None,
                  volume_guid=None,
@@ -60,6 +66,7 @@ class PhysicalSpecialParameters(object):
         self.application_parameters = application_parameters
         self.enable_system_backup = enable_system_backup
         self.file_paths = file_paths
+        self.metadata_file_path = metadata_file_path
         self.skip_nested_volumes_vec = skip_nested_volumes_vec
         self.uses_skip_nested_volumes_vec = uses_skip_nested_volumes_vec
         self.volume_guid = volume_guid
@@ -91,6 +98,7 @@ class PhysicalSpecialParameters(object):
             file_paths = list()
             for structure in dictionary.get('filePaths'):
                 file_paths.append(cohesity_management_sdk.models.file_path_parameters.FilePathParameters.from_dictionary(structure))
+        metadata_file_path = dictionary.get('metadataFilePath')
         skip_nested_volumes_vec = dictionary.get('skipNestedVolumesVec')
         uses_skip_nested_volumes_vec = dictionary.get('usesSkipNestedVolumesVec')
         volume_guid = dictionary.get('volumeGuid')
@@ -100,6 +108,7 @@ class PhysicalSpecialParameters(object):
         return cls(application_parameters,
                    enable_system_backup,
                    file_paths,
+                   metadata_file_path,
                    skip_nested_volumes_vec,
                    uses_skip_nested_volumes_vec,
                    volume_guid,
