@@ -21,6 +21,9 @@ class ProtectionPolicy(object):
             are not started. If a Job Run has been scheduled but not yet
             executed and the blackout period starts, the behavior depends on
             the policy field AbortInBlackoutPeriod.
+        cdp_scheduling_policy (SchedulingPolicy): Specifies the CDP backup
+            schedule of a Protection Job and how long log files captured by
+            this schedule are retained on the Cohesity Cluster.
         cloud_deploy_policies (list of SnapshotCloudCopyPolicy): Array of
             Cloud Deploy Policies.  Specifies settings for copying Snapshots
             to Cloud. CloudDeploy target where backup snapshots may be
@@ -48,6 +51,8 @@ class ProtectionPolicy(object):
             CBT-based backup schedule of a Protection Job and how long
             Snapshots captured by this schedule are retained on the Cohesity
             Cluster.
+        is_usable (bool): Specifies if the policy can be used to create a
+            job.
         last_modified_time_msecs (long|int): Specifies the epoch time (in
             milliseconds) when the Protection Policy was last modified.
         log_scheduling_policy (SchedulingPolicy): Specifies settings that
@@ -55,6 +60,9 @@ class ProtectionPolicy(object):
         name (string): Specifies the name of the Protection Policy.
         num_linked_policies (long|int): Species the number of policies linked
             to a global policy.
+        parent_policy_id (string): Specifies the parent global policy Id. This
+            must be specified when creating a policy from global policy
+            template.
         retries (int): Specifies the number of times to retry capturing
             Snapshots before the Job Run fails.
         retry_interval_mins (int): Specifies the number of minutes before
@@ -103,6 +111,7 @@ class ProtectionPolicy(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "blackout_periods":'blackoutPeriods',
+        "cdp_scheduling_policy":'cdpSchedulingPolicy',
         "cloud_deploy_policies":'cloudDeployPolicies',
         "days_to_keep":'daysToKeep',
         "days_to_keep_log":'daysToKeepLog',
@@ -112,10 +121,12 @@ class ProtectionPolicy(object):
         "full_scheduling_policy":'fullSchedulingPolicy',
         "id":'id',
         "incremental_scheduling_policy":'incrementalSchedulingPolicy',
+        "is_usable":'isUsable',
         "last_modified_time_msecs":'lastModifiedTimeMsecs',
         "log_scheduling_policy":'logSchedulingPolicy',
         "name":'name',
         "num_linked_policies":'numLinkedPolicies',
+        "parent_policy_id":'parentPolicyId',
         "retries":'retries',
         "retry_interval_mins":'retryIntervalMins',
         "rpo_policy_settings":'rpoPolicySettings',
@@ -130,6 +141,7 @@ class ProtectionPolicy(object):
 
     def __init__(self,
                  blackout_periods=None,
+                 cdp_scheduling_policy=None,
                  cloud_deploy_policies=None,
                  days_to_keep=None,
                  days_to_keep_log=None,
@@ -139,10 +151,12 @@ class ProtectionPolicy(object):
                  full_scheduling_policy=None,
                  id=None,
                  incremental_scheduling_policy=None,
+                 is_usable=None,
                  last_modified_time_msecs=None,
                  log_scheduling_policy=None,
                  name=None,
                  num_linked_policies=None,
+                 parent_policy_id=None,
                  retries=None,
                  retry_interval_mins=None,
                  rpo_policy_settings=None,
@@ -157,6 +171,7 @@ class ProtectionPolicy(object):
 
         # Initialize members of the class
         self.blackout_periods = blackout_periods
+        self.cdp_scheduling_policy = cdp_scheduling_policy
         self.cloud_deploy_policies = cloud_deploy_policies
         self.days_to_keep = days_to_keep
         self.days_to_keep_log = days_to_keep_log
@@ -166,10 +181,12 @@ class ProtectionPolicy(object):
         self.full_scheduling_policy = full_scheduling_policy
         self.id = id
         self.incremental_scheduling_policy = incremental_scheduling_policy
+        self.is_usable = is_usable
         self.last_modified_time_msecs = last_modified_time_msecs
         self.log_scheduling_policy = log_scheduling_policy
         self.name = name
         self.num_linked_policies = num_linked_policies
+        self.parent_policy_id = parent_policy_id
         self.retries = retries
         self.retry_interval_mins = retry_interval_mins
         self.rpo_policy_settings = rpo_policy_settings
@@ -201,6 +218,7 @@ class ProtectionPolicy(object):
 
         # Extract variables from the dictionary
         blackout_periods = None
+        cdp_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('cdpSchedulingPolicy')) if dictionary.get('cdpSchedulingPolicy') else None
         if dictionary.get('blackoutPeriods') != None:
             blackout_periods = list()
             for structure in dictionary.get('blackoutPeriods'):
@@ -222,10 +240,12 @@ class ProtectionPolicy(object):
         full_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('fullSchedulingPolicy')) if dictionary.get('fullSchedulingPolicy') else None
         id = dictionary.get('id')
         incremental_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('incrementalSchedulingPolicy')) if dictionary.get('incrementalSchedulingPolicy') else None
+        is_usable = dictionary.get('isUsable')
         last_modified_time_msecs = dictionary.get('lastModifiedTimeMsecs')
         log_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('logSchedulingPolicy')) if dictionary.get('logSchedulingPolicy') else None
         name = dictionary.get('name')
         num_linked_policies = dictionary.get('numLinkedPolicies')
+        parent_policy_id = dictionary.get('parentPolicyId')
         retries = dictionary.get('retries')
         retry_interval_mins = dictionary.get('retryIntervalMins')
         rpo_policy_settings = cohesity_management_sdk.models.rpo_policy_settings.RpoPolicySettings.from_dictionary(dictionary.get('rpoPolicySettings')) if dictionary.get('rpoPolicySettings') else None
@@ -247,6 +267,7 @@ class ProtectionPolicy(object):
 
         # Return an object of this model
         return cls(blackout_periods,
+                   cdp_scheduling_policy,
                    cloud_deploy_policies,
                    days_to_keep,
                    days_to_keep_log,
@@ -256,10 +277,12 @@ class ProtectionPolicy(object):
                    full_scheduling_policy,
                    id,
                    incremental_scheduling_policy,
+                   is_usable,
                    last_modified_time_msecs,
                    log_scheduling_policy,
                    name,
                    num_linked_policies,
+                   parent_policy_id,
                    retries,
                    retry_interval_mins,
                    rpo_policy_settings,
