@@ -10,12 +10,14 @@ class ProtocolAccessEnum(object):
     'kNFSOnly' enables protocol access to NFS only.
     'kSMBOnly' enables protocol access to SMB only.
     'kS3Only' enables protocol access to S3 only.
+    'kSwiftOnly' enables protocol access to Swift only.
 
     Attributes:
         KALL: TODO: type description here.
         KNFSONLY: TODO: type description here.
         KSMBONLY: TODO: type description here.
         KS3ONLY: TODO: type description here.
+        KSWIFTONLY: TODO: type description here.
 
     """
 
@@ -27,3 +29,4 @@ class ProtocolAccessEnum(object):
 
     KS3ONLY = 'kS3Only'
 
+    KSWIFTONLY = 'kSwiftOnly'
